.. _api:

Package API
===========

.. note:: Accessors are better documented in section :ref:`accessors`.

.. autosummary::
    :toctree: api

    xoa
    xoa.accessors
    xoa.cf
    xoa.cfgm
    xoa.cli
    xoa.color
    xoa.coords
    xoa.dyn
    xoa.filter
    xoa.geo
    xoa.grid
    xoa.interp
    xoa.misc
    xoa.plot
    xoa.regrid
    xoa.sigma
